Installation of macos-oslog project
===================================

To install the latest released version of the
macos-oslog project into your active Python environment:

      $ pip install macos-oslog

This will also install any prerequisite Python packages.

For more details and alternative ways to install, see
[Installation](https://andy-maier.github.io/macos-oslog/html/docs/install.html#installation).
